@@ -3,7 +3,8 @@ import {DialogComponent} from '@eg/share/dialog/dialog.component';
 
 @Component({
     selector: 'eg-alert-dialog',
-    templateUrl: './alert.component.html'
+    templateUrl: './alert.component.html',
+    styles: ['.modal-alert.modal-body:is(:focus, :focus-visible) { outline: 0.25rem solid var(--bs-border-color-translucent); }']
 })
 
 /**
